@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -71,11 +71,19 @@ namespace OrthancWSI
       Orthanc::HttpClient::GlobalInitialize();
       Orthanc::FromDcmtkBridge::InitializeDictionary(false /* don't load private dictionary */);
       assert(DisplayPerformanceWarning());
+
+#if ORTHANC_ENABLE_DCMTK_TRANSCODING == 1
+      Orthanc::FromDcmtkBridge::InitializeCodecs();
+#endif
     }
 
 
     void GlobalFinalize()
     {
+#if ORTHANC_ENABLE_DCMTK_TRANSCODING == 1
+      Orthanc::FromDcmtkBridge::FinalizeCodecs();
+#endif
+
       OrthancWSI::OpenSlideLibrary::Finalize();
       Orthanc::HttpClient::GlobalFinalize();
       Orthanc::Toolbox::FinalizeOpenSsl();
@@ -222,8 +230,8 @@ namespace OrthancWSI
         << "Copyright (C) 2012-2016 Sebastien Jodogne, "
         << "Medical Physics Department, University Hospital of Liege (Belgium)" << std::endl
         << "Copyright (C) 2017-2023 Osimis S.A. (Belgium)" << std::endl
-        << "Copyright (C) 2024-2024 Orthanc Team SRL (Belgium)" << std::endl
-        << "Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain (Belgium)" << std::endl
+        << "Copyright (C) 2024-2025 Orthanc Team SRL (Belgium)" << std::endl
+        << "Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain (Belgium)" << std::endl
         << "Licensing AGPL: GNU AGPL version 3 or later <http://gnu.org/licenses/agpl.html>." << std::endl
         << "This is free software: you are free to change and redistribute it." << std::endl
         << "There is NO WARRANTY, to the extent permitted by law." << std::endl
