@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -248,14 +248,22 @@ static void Recompress(OrthancWSI::IFileTarget& output,
       switch (parameters.GetTargetCompression())
       {
         case OrthancWSI::ImageCompression_Jpeg:
-        case OrthancWSI::ImageCompression_Jpeg2000:
           targetPhotometric = Orthanc::PhotometricInterpretation_YBRFull422;
           break;
 
+        case OrthancWSI::ImageCompression_Jpeg2000:
+          // Was set to Orthanc::PhotometricInterpretation_YBRFull422 in WSI <= 3.1
+          targetPhotometric = Orthanc::PhotometricInterpretation_RGB;
+          break;
+
         case OrthancWSI::ImageCompression_None:
           targetPhotometric = Orthanc::PhotometricInterpretation_RGB;
           break;
 
+        case OrthancWSI::ImageCompression_JpegLS:
+          targetPhotometric = Orthanc::PhotometricInterpretation_RGB;
+          break;
+
         default:
           throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
       }
@@ -481,8 +489,17 @@ static void EnrichDataset(DcmDataset& dataset,
     OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_LossyImageCompression, "00");
   }
 
-  OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeWidth, boost::lexical_cast<std::string>(volume.GetWidth()));
-  OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeHeight, boost::lexical_cast<std::string>(volume.GetHeight()));
+  // In WSI <= 3.0, imaged volume width/height were filled even if no information about the imaged volume size was available
+  if (volume.HasWidth())
+  {
+    OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeWidth, boost::lexical_cast<std::string>(volume.GetWidth()));
+  }
+
+  if (volume.HasHeight())
+  {
+    OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeHeight, boost::lexical_cast<std::string>(volume.GetHeight()));
+  }
+
   OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeDepth, boost::lexical_cast<std::string>(volume.GetDepth()));
 
   std::unique_ptr<DcmItem> origin(new DcmItem);
@@ -661,7 +678,7 @@ static bool ParseParameters(int& exitStatus,
     (OPTION_TILE_HEIGHT, boost::program_options::value<int>(),
      "Height of the tiles in the target image")
     (OPTION_COMPRESSION, boost::program_options::value<std::string>(), 
-     "Compression of the target image (\"none\", \"jpeg\" or \"jpeg2000\")")
+     "Compression of the target image (\"none\", \"jpeg\", \"jpeg2000\", or \"jpeg-ls\")")
     (OPTION_JPEG_QUALITY, boost::program_options::value<int>(),
      "Set quality level for JPEG (0..100)")
     (OPTION_MAX_SIZE, boost::program_options::value<int>()->default_value(10),
@@ -947,6 +964,10 @@ static bool ParseParameters(int& exitStatus,
     {
       parameters.SetTargetCompression(OrthancWSI::ImageCompression_Jpeg2000);
     }
+    else if (s == "jpeg-ls")
+    {
+      parameters.SetTargetCompression(OrthancWSI::ImageCompression_JpegLS);
+    }
     else
     {
       LOG(ERROR) << "Unknown image compression for the target image: " << s;
@@ -1121,6 +1142,24 @@ OrthancWSI::ITiledPyramid* OpenInputPyramid(OrthancWSI::ImageCompression& source
       {
         std::unique_ptr<OrthancWSI::HierarchicalTiff> tiff(new OrthancWSI::HierarchicalTiff(path));
         sourceCompression = tiff->GetImageCompression();
+
+        // New in WSI 3.1
+        double width, height;
+        if (tiff->LookupImagedVolumeSize(width, height))
+        {
+          if (!volume.HasWidth())
+          {
+            volume.SetWidth(width);
+            LOG(WARNING) << "Width of the imaged volume according to TIFF metadata: " << width << "mm";
+          }
+
+          if (!volume.HasHeight())
+          {
+            volume.SetHeight(height);
+            LOG(WARNING) << "Height of the imaged volume according to TIFF metadata: " << height << "mm";
+          }
+        }
+
         return tiff.release();
       }
       catch (Orthanc::OrthancException&)
@@ -1222,14 +1261,36 @@ int main(int argc, char* argv[])
         throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
       }
 
-      // In the 2 lines below, remember to switch X/Y when going from physical to pixel coordinates!
-      float pixelSpacingX = volume.GetWidth() / static_cast<float>(source->GetLevelHeight(0));
-      float pixelSpacingY = volume.GetHeight() / static_cast<float>(source->GetLevelWidth(0));
-      if (std::abs(pixelSpacingX - pixelSpacingY) >= 100.0f * std::numeric_limits<float>::epsilon())
+      // In the lines below, remember to switch X/Y when going from physical to pixel coordinates!
+      if (volume.HasWidth() &&
+          volume.HasHeight())
       {
-        LOG(WARNING) << "Your pixel spacing is different along the X and Y axes, make sure that "
-                     << "you have not inversed the --" << OPTION_IMAGED_WIDTH << " and the --"
-                     << OPTION_IMAGED_HEIGHT << " options: " << pixelSpacingX << " vs. " << pixelSpacingY;
+        float pixelSpacingX = volume.GetWidth() / static_cast<float>(source->GetLevelHeight(0));
+        float pixelSpacingY = volume.GetHeight() / static_cast<float>(source->GetLevelWidth(0));
+        if (!OrthancWSI::ImageToolbox::IsNear(pixelSpacingX, pixelSpacingY))
+        {
+          LOG(WARNING) << "Your pixel spacing is different along the X and Y axes, make sure that "
+                       << "you have not inversed the --" << OPTION_IMAGED_WIDTH << " and the --"
+                       << OPTION_IMAGED_HEIGHT << " options: " << pixelSpacingX << " vs. " << pixelSpacingY;
+        }
+      }
+      else if (!volume.HasWidth() &&
+               !volume.HasHeight())
+      {
+        LOG(WARNING) << "Unknown imaged volume size, use the --" << OPTION_IMAGED_WIDTH << " and the --"
+                     << OPTION_IMAGED_HEIGHT << " options to fill the (0048,0001) and (0048,0002) DICOM tags";
+      }
+      else if (volume.HasWidth())
+      {
+        assert(!volume.HasHeight());
+        volume.SetHeight(volume.GetWidth() / static_cast<float>(source->GetLevelHeight(0)) *
+                         static_cast<float>(source->GetLevelWidth(0)));
+      }
+      else
+      {
+        assert(!volume.HasWidth());
+        volume.SetWidth(volume.GetHeight() / static_cast<float>(source->GetLevelWidth(0)) *
+                        static_cast<float>(source->GetLevelHeight(0)));
       }
 
       LOG(WARNING) << "Compression of the individual source tiles: " << OrthancWSI::EnumerationToString(sourceCompression);
@@ -1244,7 +1305,7 @@ int main(int argc, char* argv[])
   }
   catch (Orthanc::OrthancException& e)
   {
-    LOG(ERROR) << "Terminating on exception: " << e.What();
+    LOG(ERROR) << "Terminating on exception: " << e.What() << ": " << e.GetDetails();
     exitStatus = -1;
   }
 
