@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -42,7 +42,9 @@ namespace OrthancWSI
     ImageCompression_Png = 4,
     ImageCompression_Jpeg = 5,
     ImageCompression_Jpeg2000 = 6,
-    ImageCompression_Tiff = 7
+    ImageCompression_Tiff = 7,
+    ImageCompression_UseOrthancPreview = 8,
+    ImageCompression_JpegLS = 9
   };
 
   enum OpticalPath
