@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -33,6 +33,9 @@ namespace OrthancWSI
 {
   namespace ImageToolbox
   {
+    bool IsNear(double a,
+                double b);
+
     Orthanc::ImageAccessor* Allocate(Orthanc::PixelFormat format,
                                      unsigned int width,
                                      unsigned int height);
@@ -55,6 +58,9 @@ namespace OrthancWSI
                                           unsigned int width,
                                           unsigned int height);
     
+    void EncodeUncompressedTile(std::string& target,
+                                const Orthanc::ImageAccessor& source);
+
     void EncodeTile(std::string& target,
                     const Orthanc::ImageAccessor& source,
                     ImageCompression compression,
@@ -74,5 +80,9 @@ namespace OrthancWSI
     void ConvertJpegYCbCrToRgb(Orthanc::ImageAccessor& image /* inplace */);
 
     ImageCompression Convert(Orthanc::MimeType type);
+
+    bool HasPngSignature(const std::string& buffer);
+
+    bool HasJpegSignature(const std::string& buffer);
   }
 }
