@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -41,6 +41,7 @@
 #endif
 
 #define SERIALIZED_METADATA  "4201"   // Was "4200" if versions <= 0.7 of this plugin
+#define SERIALIZED_VERSION   "2"      // Introduced in WSI 3.1
 
 
 namespace OrthancWSI
@@ -53,6 +54,8 @@ namespace OrthancWSI
   static const Orthanc::DicomTag DICOM_TAG_TOTAL_PIXEL_MATRIX_ROWS(0x0048, 0x0007);
   static const Orthanc::DicomTag DICOM_TAG_IMAGE_TYPE(0x0008, 0x0008);
   static const Orthanc::DicomTag DICOM_TAG_RECOMMENDED_ABSENT_PIXEL_CIELAB(0x0048, 0x0015);
+  static const Orthanc::DicomTag DICOM_TAG_IMAGED_VOLUME_WIDTH(0x0048, 0x0001);
+  static const Orthanc::DicomTag DICOM_TAG_IMAGED_VOLUME_HEIGHT(0x0048, 0x0002);
 
   static ImageCompression DetectImageCompression(OrthancStone::IOrthancConnection& orthanc,
                                                  const std::string& instanceId)
@@ -79,6 +82,17 @@ namespace OrthancWSI
     {
       return ImageCompression_Jpeg2000;
     }
+    else if (s == "1.2.840.10008.1.2.1.99" ||
+             s == "1.2.840.10008.1.2.2"    ||
+             s == "1.2.840.10008.1.2.4.51" ||
+             s == "1.2.840.10008.1.2.4.57" ||
+             s == "1.2.840.10008.1.2.4.70" ||
+             s == "1.2.840.10008.1.2.4.80" ||
+             s == "1.2.840.10008.1.2.4.81" ||
+             s == "1.2.840.10008.1.2.5")
+    {
+      return ImageCompression_UseOrthancPreview;
+    }
     else
     {
       LOG(ERROR) << "Unsupported transfer syntax: " << s;
@@ -282,6 +296,11 @@ namespace OrthancWSI
         backgroundBlue_ = rgb.GetB();
       }
     }
+
+    // New in WSI 3.1
+    hasImagedVolumeSize_ = (
+      reader.GetDoubleValue(imagedVolumeWidth_, Orthanc::DicomPath(DICOM_TAG_IMAGED_VOLUME_WIDTH)) &&
+      reader.GetDoubleValue(imagedVolumeHeight_, Orthanc::DicomPath(DICOM_TAG_IMAGED_VOLUME_HEIGHT)));
   }
 
 
@@ -294,7 +313,12 @@ namespace OrthancWSI
     hasBackgroundColor_(false),
     backgroundRed_(0),
     backgroundGreen_(0),
-    backgroundBlue_(0)
+    backgroundBlue_(0),
+    hasImagedVolumeSize_(false),
+    imagedVolumeWidth_(0),
+    imagedVolumeHeight_(0),
+    hasLevel_(false),
+    level_(0)
   {
     if (useCache)
     {
@@ -303,8 +327,10 @@ namespace OrthancWSI
         // Try and deserialized the cached information about this instance
         std::string serialized;
         orthanc.RestApiGet(serialized, "/instances/" + instanceId + "/metadata/" + SERIALIZED_METADATA);
-        Deserialize(serialized);
-        return;  // Success
+        if (Deserialize(serialized))
+        {
+          return;  // Success
+        }
       }
       catch (Orthanc::OrthancException&)
       {
@@ -351,6 +377,8 @@ namespace OrthancWSI
   static const char* const PHOTOMETRIC_INTERPRETATION = "PhotometricInterpretation";
   static const char* const IMAGE_TYPE = "ImageType";
   static const char* const BACKGROUND_COLOR = "BackgroundColor";
+  static const char* const VERSION = "Version";
+  static const char* const IMAGED_VOLUME_SIZE = "ImagedVolumeSize";
   
   
   void DicomPyramidInstance::Serialize(std::string& result) const
@@ -378,6 +406,7 @@ namespace OrthancWSI
     content[TOTAL_HEIGHT] = totalHeight_;
     content[PHOTOMETRIC_INTERPRETATION] = Orthanc::EnumerationToString(photometric_);
     content[IMAGE_TYPE] = imageType_;
+    content[VERSION] = SERIALIZED_VERSION;
 
     if (hasBackgroundColor_)
     {
@@ -388,6 +417,14 @@ namespace OrthancWSI
       content[BACKGROUND_COLOR] = color;
     }
 
+    if (hasImagedVolumeSize_)
+    {
+      Json::Value size = Json::arrayValue;
+      size.append(imagedVolumeWidth_);
+      size.append(imagedVolumeHeight_);
+      content[IMAGED_VOLUME_SIZE] = size;
+    }
+
 #if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 9, 0)
     Orthanc::Toolbox::WriteFastJson(result, content);
 #else
@@ -397,7 +434,7 @@ namespace OrthancWSI
   }
 
 
-  void DicomPyramidInstance::Deserialize(const std::string& s)
+  bool DicomPyramidInstance::Deserialize(const std::string& s)
   {
     Json::Value content;
     OrthancStone::IOrthancConnection::ParseJson(content, s);
@@ -409,6 +446,12 @@ namespace OrthancWSI
       throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
     }
 
+    std::string version = Orthanc::SerializationToolbox::ReadString(content, VERSION, "1");
+    if (version != SERIALIZED_VERSION)
+    {
+      return false;  // Serialized using a different version of the plugin, must be reconstructed
+    }
+
     hasCompression_ = Orthanc::SerializationToolbox::ReadBoolean(content, HAS_COMPRESSION);
     compression_ = static_cast<ImageCompression>(Orthanc::SerializationToolbox::ReadInteger(content, IMAGE_COMPRESSION));
     format_ = static_cast<Orthanc::PixelFormat>(Orthanc::SerializationToolbox::ReadInteger(content, PIXEL_FORMAT));
@@ -457,6 +500,23 @@ namespace OrthancWSI
         backgroundBlue_ = color[2].asUInt();
       }
     }
+
+    hasImagedVolumeSize_ = false;
+    if (content.isMember(IMAGED_VOLUME_SIZE))
+    {
+      const Json::Value& size = content[IMAGED_VOLUME_SIZE];
+      if (size.type() == Json::arrayValue &&
+          size.size() == 2u &&
+          size[0].isDouble() &&
+          size[1].isDouble())
+      {
+        hasImagedVolumeSize_ = true;
+        imagedVolumeWidth_ = size[0].asDouble();
+        imagedVolumeHeight_ = size[1].asDouble();
+      }
+    }
+
+    return true;  // Success
   }
 
 
@@ -497,4 +557,51 @@ namespace OrthancWSI
       throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls);
     }
   }
+
+
+  double DicomPyramidInstance::GetImagedVolumeWidth() const
+  {
+    if (hasImagedVolumeSize_)
+    {
+      return imagedVolumeWidth_;
+    }
+    else
+    {
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls);
+    }
+  }
+
+
+  double DicomPyramidInstance::GetImagedVolumeHeight() const
+  {
+    if (hasImagedVolumeSize_)
+    {
+      return imagedVolumeHeight_;
+    }
+    else
+    {
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls);
+    }
+  }
+
+
+  void DicomPyramidInstance::SetLevel(unsigned int level)
+  {
+    if (hasLevel_)
+    {
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls);
+    }
+    else
+    {
+      level_ = level;
+      hasLevel_ = true;
+    }
+  }
+
+
+  bool DicomPyramidInstance::IsLevel(unsigned int level) const
+  {
+    return (hasLevel_ &&
+            level_ == level);
+  }
 }
