@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -40,6 +40,7 @@ namespace OrthancWSI
       unsigned int  width_;
       unsigned int  height_;
       std::string  headers_;
+      std::string  description_;
 
       Level(TIFF* tiff,
             tdir_t    directory,
@@ -102,5 +103,8 @@ namespace OrthancWSI
     {
       return compression_;
     }
+
+    bool LookupImagedVolumeSize(double& width,
+                                double& height) const;
   };
 }
