@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,6 +25,7 @@
 #include "DicomPyramidWriter.h"
 
 #include "../DicomToolbox.h"
+#include "../ImageToolbox.h"
 
 #include <Compatibility.h>  // For std::unique_ptr
 #include <Logging.h>
@@ -198,6 +199,21 @@ namespace OrthancWSI
   }
 
 
+  void DicomPyramidWriter::EncodeTileInternal(std::string& encoded,
+                                              const Orthanc::ImageAccessor& tile)
+  {
+    if (GetImageCompression() == ImageCompression_JpegLS)
+    {
+      // For JPEG-LS, images are first store uncompressed, then transcoded in "MultiframeDicomWriter"
+      ImageToolbox::EncodeUncompressedTile(encoded, tile);
+    }
+    else
+    {
+      ImageToolbox::EncodeTile(encoded, tile, GetImageCompression(), GetJpegQuality());
+    }
+  }
+
+
   DicomPyramidWriter::DicomPyramidWriter(IFileTarget&  target,
                                          const DcmDataset& dataset,
                                          Orthanc::PixelFormat pixelFormat,
