@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -31,6 +31,7 @@
 #include <Compatibility.h>  // For std::unique_ptr
 #include <Images/ImageProcessing.h>
 #include <Images/JpegReader.h>
+#include <Images/PngReader.h>
 #include <Images/PngWriter.h>
 #include <MultiThreading/Semaphore.h>
 #include <OrthancException.h>
@@ -56,7 +57,12 @@ namespace OrthancWSI
         std::unique_ptr<Jpeg2000Reader> decoded(new Jpeg2000Reader);
         decoded->ReadFromMemory(tile_);
 
-        if (photometric_ == Orthanc::PhotometricInterpretation_YBR_ICT)
+        if (photometric_ == Orthanc::PhotometricInterpretation_YBRFull ||
+            photometric_ == Orthanc::PhotometricInterpretation_YBRFull422 ||
+            photometric_ == Orthanc::PhotometricInterpretation_YBRPartial420 ||
+            photometric_ == Orthanc::PhotometricInterpretation_YBRPartial422 ||
+            photometric_ == Orthanc::PhotometricInterpretation_YBR_ICT ||
+            photometric_ == Orthanc::PhotometricInterpretation_YBR_RCT)
         {
           ImageToolbox::ConvertJpegYCbCrToRgb(*decoded);
         }
@@ -78,6 +84,19 @@ namespace OrthancWSI
         return decoded.release();
       }
 
+      case ImageCompression_Png:
+      {
+        /**
+         * This is used if the DICOM instance has a transfer syntax
+         * that is not natively supported by the WSI viewer plugin, in
+         * which case the tile comes from the "/preview" route of the
+         * REST API of Orthanc.
+         **/
+        std::unique_ptr<Orthanc::PngReader> decoded(new Orthanc::PngReader);
+        decoded->ReadFromMemory(tile_);
+        return decoded.release();
+      }
+
       default:
         throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented);
     }
